@@ -217,11 +217,17 @@ omniPy::ensureOmniThread()
     return 0;
   }
 
+#if (PY_VERSION_HEX < 0x03000000)
   PyObject* current = PyObject_CallMethod(threading,
 					  (char*)"currentThread",
 					  (char*)"");
+#else
+  PyObject* current = PyObject_CallMethod(threading,
+					  (char*)"current_thread",
+					  (char*)"");
+#endif
   if (!current) {
-    omniORB::logs(1, "Unexpected exception calling threading.currentThread.");
+    omniORB::logs(1, "Unexpected exception calling threading.current_thread.");
     if (omniORB::trace(1)) PyErr_Print();
     PyErr_Clear();
     return 0;
@@ -761,15 +767,15 @@ extern "C" {
   static PyObject* pyomni_setClientCallTimeout(PyObject* self, PyObject* args)
   {
     if (PyTuple_GET_SIZE(args) == 1) {
-      int timeout;
-      if (!PyArg_ParseTuple(args, (char*)"i", &timeout))
+      unsigned long timeout;
+      if (!PyArg_ParseTuple(args, (char*)"k", &timeout))
 	return 0;
       omniORB::setClientCallTimeout(timeout);
     }
     else {
-      int timeout;
+      unsigned long timeout;
       PyObject* pyobjref;
-      if (!PyArg_ParseTuple(args, (char*)"Oi", &pyobjref, &timeout))
+      if (!PyArg_ParseTuple(args, (char*)"Ok", &pyobjref, &timeout))
 	return 0;
 
       CORBA::Object_ptr objref = omniPy::getObjRef(pyobjref);
@@ -790,8 +796,8 @@ extern "C" {
   static PyObject* pyomni_setClientThreadCallTimeout(PyObject* self,
 						     PyObject* args)
   {
-    int timeout;
-    if (!PyArg_ParseTuple(args, (char*)"i", &timeout))
+    unsigned long timeout;
+    if (!PyArg_ParseTuple(args, (char*)"k", &timeout))
       return 0;
 
     try {
@@ -838,8 +844,8 @@ extern "C" {
   static PyObject* pyomni_setClientConnectTimeout(PyObject* self,
 						  PyObject* args)
   {
-    int timeout;
-    if (!PyArg_ParseTuple(args, (char*)"i", &timeout))
+    unsigned long timeout;
+    if (!PyArg_ParseTuple(args, (char*)"k", &timeout))
       return 0;
 
     omniORB::setClientConnectTimeout(timeout);
